# 文档索引

这里存放了 YakultPDF 的详细文档。

## 💡 入门必读

- **[快速开始](00.快速开始.md)**
    - 5 分钟极速上手
    - 生成第一个 PDF

- **[工作区使用指南](01.工作区使用指南.md)**
    - 从零开始建立 PDF 生成工作区
    - 目录结构最佳实践
    - 环境配置

- **[配置指南](03.配置指南.md)**
    - `mark2pdf.config.toml` 配置层级
    - Frontmatter 元数据详解
    - 样式定制

- **[CLI使用说明](02.CLI使用说明.md)**
    - 完整的命令行参数参考
    - 子命令详解 (`convert`, `mdimage`, `init` 等)

- **[FAQ](05.FAQ.md)**
    - 常见问题解答
    - 故障排除

## 🎨 进阶主题

- **[模板语法指南](04.模板语法指南.md)**
    - NB 模板的高级特性
    - 整页图片、背景页、多栏布局语法

- **[项目说明文档](06.项目说明文档.md)**
    - 系统架构说明
    - 模块设计与开发指南

- **[docker版使用说明](07.docker版使用说明.md)**
    - 使用 Docker 容器运行
    - 字体挂载说明
